bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 21. Aventiure
___________________________________________________ #### <Aventivr wie si hin fvr>
| ### ie boten lazen rite wir svln iv tuon bekant ### wie div kvniginne gefuor durch div lant ### oder wa fon ir schieden Gyselher vn– Gernot ### si heten ir gedienet als in ir triwe daz gebot
###### 1231 | ### Vnz an die Tvonowe ze Uergen si do riten ### si begunden vrlovbes die kvnniginne biten ### wan si wider wolten riten an den Rin ### done mohtenz ane weinen von guoten vriunten niht gesin
###### 1232 | ### Giselher der snelle sprach zer swester sin ### swenne daz dv frovwe beduerfen wolles min [50b] ### ob ir iht gewerre daz tuo mir bekant ### so rite ich dir ce dienest in daz Ecelen lant
###### 1233 | ### Die ir mage waren chvstens an den mvnt ### vil minneclichen scheiden sach man an der stvnt ### von Ruedigers frivnden des marchgrauen man ### do fuort div kvniginne vil manige meit wolgetan
###### 1234 | ### Hvndert vn– viere die truogen richiv cleit ### von gemalt richen pfellen vil der schilte bereit ### fuorte man bi der vrowen nahen vf den wegen ### do kerte von ir dannen vil manich herlicher degen
###### 1235 | ### Si zogten balde dannen nider durch Beier lant ### do sagte die mere da weren fur gerant ### vil vnkvnder geste da noch ein closter stat ### vn– da daz In mit fluzze in die Tuonouwe gat
###### 1236 | ### In der stat ze Pazzouwe saz ein bischof ### die berge die wurden lere vn– ovch des fursten <hof> ### si ilten balde vf in Beier lant ### da der bischof Pilgerin die schoenen Kriemhilt vant
###### 1237 | ### Den reken von dem lande was do niht ze leit ### do si ir volgen sahen so manige schoene meit ### da trute man mit ovgen der edelen riter kint ### guote herberge gap man den gesten allen sint
###### 1238 | ### Der bischof mit siner niftel ze Pazzouwe reit ### do daz den Burgonden von der stat wart geseit ### daz da cheme Kriemhilt des fursten swester kint ### div wart wol enphangen von den coufluten sint
###### 1239 | ### Daz si beliben solten der bischof het des wan ### do sprach der herre Ekewart daz ist vngetan ### wir mvozen varen widere in Ruedigers lant ### vns wartent vil der degene wan ez ist in allen wol bekant
###### 1240 | ### Div mere nv wol wesse div schoene Gothelint ### si bereite sich mit flize vn– ir vil edele kint ### in het enboten Ruediger daz in daz duhte guot ### daz si der kvnniginne da mit troste den mvot
###### 1241 | ### daz si ir rite engegene mit den sinen man ### vf zuo der Ense do daz wart getan ### do sach man allenthalben die wege vil vnmuozec sten ### si begvnden gegen gen gesten beide riten vn– gen
###### 1242 | ### Nv was div kvniginne ze E^verdingen komen ### gnuge uz Beierlande solten han genomen ### den rovb vf der strazen nach ir gewoneheit ### so hete si den gesten da getan vil lihte leit
###### 1243 | ### Daz was wol vnderstanden von dem marcgrauen her ### er fuorte tvsent riter vn– dannoch mer ### do was ovch komen Gothelint Rudigers wip ### mit ir komen herliche vil maniges guoten reken lip
###### 1244 | ### Do si vber die Truone komen in Ense vf daz velt ### do sach man vf gespannen hutten vn– gezelt ### da die geste solten die nahtsedle han ### div chost div was den reken da von Ruedigere getan [51a]
###### 1245 | ### Gotelint div schoene die herberge lie ### hinder ir beliben vf den wegen gie ### mit klinginden zovmen manic pferit wolgetan ### der antphanc wart vil schoene liep waz ez Rudiger getan
###### 1246 | ### Die in ze beiden siten chomen vf den wegen ### die riten lobeliche der was vil manich degen ### si pflagen riterschefte daz sach vil manich meit ### ez was der kvnneginne der riter dienst niht leit
###### 1247 | ### Do zuo den gestesten komen die Ruedigers man ### vil der trunzuone sach man ze berge gan ### von der reken hende mit riterlichen siten ### da wart wol ze prise vor den vrowen geriten
###### 1248 | ### Daz liezen beliben do gruozte manich man ### vil guotlichen an ander do fuorten si von dan ### die schoene Gottelinde da si Kriemhilt sach ### die vrovwen diende konden die heten cleinen gemach
###### 1249 | ### Der vogt von Bechelaren ze sime wibe reit ### der edelen marchgrauinne was daz niht ze leit ### der er so wol gesvnder von Rine was komen ### ir was ein teil ir swere mit grozen vreuden benomen
###### 1250 | ### Do sin hete enphangen er hiez sich vf daz gras ### erbeizen mit den vrovwen swaz ir da mit ir was ### da wart vil vmmuozech manich edel man ### den vrovwen wart do dienest mit grozen flize getan
###### 1251 | ### Do sach div vrovwe Kriemnhilt die marchgrauinne sten ### mit dem ir gesinde si lie niht nach ir gen ### daz phert mit dem zovme zvchen si began ### vn– bat sich snelleclichen von dem satele eben dan
###### 1252 | ### Den bischof sach man wisen siner swester kint ### in vn– Echewarten zuo Gothelinde sint ### da wart vil michel wiken an der selben stunt ### do kuste div ellende an Gothelinde mvnt
###### 1253 | ### Do sprach vil minnecliche des Ruedigers wip ### nv wol mich liebe vrovwe daz ich iwren schoenen lip ### han in disem lande mit ovgen min gesehen ### mir erkonde an disen citen nimmer lieber geschehen
###### 1254 | ### Nv lon iv got sprach Criemhilt vil edele Gothelint ### sol ich gesunt beliben vn– Botlvnges kint ### ez mag iv komen ze liebe daz ir mich habet gesehen ### in beiden was vnkvnt daz sider mvose geschehen
###### 1255 | ### Mit zuhten zuo an ander gie vil manich meit ### do waren in die reken mit dienste vil bereit ### si sazen nach dem gruoze nider uf den cle ### si gewunnen maniger kvnde die in vil vremde waren ê
###### 1256 | ### Man hiez den vrovwen schenken ez was wol mitter tac ### daz edel ingesinde da niht lenger lac ### si riten da si vunden manige huotten breit ### da was den edelen gesten vil michel dienst bereit
###### 1257 | ### Die naht si hete ruowe vnz an den morgen vruo ### die von Bechelaren bereiten sich darzuo [51b] ### wie si behalten solten vil manigen werden gast ### wol hete gehandelt Ruediger daz im da wenich iht gebrast
###### 1258 | ### Die venster an den muoren sach man offen stan ### div bvrch ze Bekelaren div was vf getan ### do riten darin die geste die man vil gerne sach ### den hiez der wirt vil edele schaffen guoten gemach
###### 1259 | ### Diu Rudigeres tohter mit ir gesinde gie ### da si die kunneginne vil minnechlich enphie ### da was ovch ir mvoter des marchgrauen wip ### mit liebe wart gegruozet vil maniger iunchvrowen lip
###### 1260 | ### Si viengen sich behanden vn– giengen dan ### in einen palas witen der was vil wol getan ### da div Tuonouwe vnder hine floz ### si sazen gen den luften vn– heten chvrzewile groz
###### 1261 | ### Wes si da mer pflagen dis en kan ich niht gesagen ### daz in so vbel zovgte daz horte man do klagen ### die Kriemhilde reken wand ez was in leit ### hei waz do guoter reken mit in von Bechelaren reit
###### 1262 | ### Vil minneclichen dienest Ruediger in bot ### do gap div kunniginne zvelf arbovgen rot ### der Gotlinde tohter vn– also gvot gewant ### daz si niht bezzers brahte in daz lant
###### 1263 | ### Swie ir genomen were der Niblvnge <golt> ### alle die si gesahen die mahte si ir holt ### noch mit dem chleinen guote daz si da mohte han ### des wirtes ingesinde dem wart groze gabe getan
###### 1264 | ### Da wider bot do ere div vrovwe Gotlint ### den gesten von dem Rine so guotlichen sint ### daz man der vremden harte wenic vant ### sin truogen ir gesteine oder ir herlich gewant
###### 1265 | ### Do si enbizzen waren vn– daz si solten dan ### von der husvrowen wart geboten an ### getriwelichen dienest daz Ecelen wip ### da wart vil getrivtet der schoenen iuncvrovwen <lip>
###### 1266 | ### Si sprach zuo der kunneginne swenne iuch nu dunket guot ### ich waiz wol daz ez gerne min lieber vater tuot ### daz er mich zuo ziv sendet in der Hunen lant ### daz ir getriwe wære wie wol daz Kriemhilt eruant
###### 1267 | ### Div ros bereitet waren vn fur Bechelaren komen ### do het div edel kvnnegin vrlovp nu genomen ### von Rudigers wibe vn– der tohter sin ### do sciet ovch sich mit gruoze vil manic schoene magetin
###### 1268 | ### An nander si vil selten sahen nach den tagen ### vz Medilke wart uf handen vil getragen ### manich goltvaz rich darinne brahte man win ### den gesten zuo der straze si muosen willechomen sin
###### 1269 | ### Ein wirt was da gesezzen Astolt genant ### der wisete si die straze in daz Osterlant ### gegen Mûtaren die Tvonowe nider ### da wart vil wol gedienet der <schonen> kvniginne sider [52a]
###### 1270 | ### Der bischof vrivntliche von siner nifteln schiet ### daz si sich wol gehabete wie vast er ir daz riet ### vn– daz si ir ere kovfte so Helke hete getan ### hei waz si grozer eren sid ce den Hunen gewan
###### 1271 | ### Zuo der Trevsem brahte man die geste dan ### ir phlagen vlizeclichen die Ruedigers man ### vnz daz die Hunen riten vber lant ### do wart der kvniginne vil michel ere bekant
###### 1272 | ### Bi der Treisem hete der kvnich vz Hûnen lant ### eine burch wite div was wol bekant ### geheizen Zeizenmvre vrov Helche saz da ê ### vn– pflac so grozer tvgende daz wetlich nimmer mer erge
###### 1273 | ### ez tæte danne Kriemhilt div also kvnde geben ### si mohte nach ir leide daz liep wol geleben ### daz ir ovch iahen ere die Ecelen man ### der si sid grozen vollen bi den helden gewan
###### 1274 | ### Ecelen herschaft was witen erkant ### daz man ze allen ziten in sime hove vant ### die kuonsten reken von den ie wart vernomen ### vnder kristen vn– heiden die waren mit in allen komen
###### 1275 | ### Bi im was alle zit daz wætlich mer erge ### kristenlicher orden vn– ovch der heiden ê ### in swie getanem lebne sich islicher truoc ### das schuof des kuniges <milte> daz man in allen gap genuoch

<<< Übersicht <<< vorige Seite nächste Seite >>>